/**
 * C++ Class    Dynamic Data Scaler
 *
 * Revision     1.0a (9th August 2010)
 * Programmer   Michael Allwright
 *
 * Purpose      The Dynamic Data Scaler is used to scale the statisitics for individual flows
 *              into values which can be projected onto L3DGEWorld entities. Before using the
 *              using the scaler, it must be calibrated with all the data that is to be scaled.
 *              This creates a two pass situation. On the first pass, you must pass all new
 *              statistics data to the calibrateScaler method. On the seconds pass you can run each
 *              value through the scaleToMetric method to get a scaled value.
 *
 * TODO / BUG   Currently the data scaler takes the minimum and maximum values and scales the flow
 *              characteristic's statistic linearly between these values. This has 2 problems, 1.
 *              Dynamic scaling between iterations can give the perspective that network conditions
 *              are changing when metrics are just being rescaled, 2. The maximum and minimum values
 *              are sensitive to noise. - this could be fixed using the 5th & 95th percentiles to
 *              filter away the outliers
**/

#ifndef _LTCPMON_DATASCALER_
#define _LTCPMON_DATASCALER_

#include <vector>
#include "bounds.h"

class DataScaler
{
    public:
        DataScaler();
        void resetScaler();
        void calibrateScaler(double quantity, unsigned int flowChar, unsigned int statMode);
        double scaleToMetric(double quantity, unsigned int flowChar, unsigned int statMode, unsigned int metric);

    private:
        std::vector< std::vector<bounds> > parameterBounds;
};

#endif
