/**
 * C++ Class    Entity File Parser
 *
 * Revision     1.0a (9th August 2010)
 * Programmer   Michael Allwright
 *
 * Purpose      Entity File Parser is designed to parse a set of entities out of a given file and manage associations
 *              between the entities and the TCP flow.
 *
 *              The class contains several overloaded methods which allow you to set/get an association and to remove
 *              an association based on the entities UID or tcpflow ID (used in the flow map)...
 *
 * NOTE | BUG   If attempting to fix or improve the removal logic, check the reset association method logic here
 *              possible source for bugs...
**/

#ifndef _LTCPMON_ENTITYPARSER_
#define _LTCPMON_ENTITYPARSER_

#include <fstream>
#include <string>
#include <vector>

#include "entitymapping.h"

class EntityFileParser
{
    public:
        EntityFileParser();
        EntityFileParser(const std::string & hostsFilename);

        void parse();

        const std::string & getFilename() const;
        const std::vector<EntityMapping> & getEntityMappings() const;

        unsigned int setEntityAssociation(const std::string & tcpFlowID);

        bool removeEntityAssociation(unsigned int entityID);
        bool removeEntityAssociation(const std::string & tcpFlowID);

        unsigned int getNumberOfEntities() const;
        unsigned int getNumberOfAssignedEntities() const;

    private:
        std::string entityFilename;
        std::ifstream entityFile;

        unsigned int numberOfEntities, numberOfAssignedEntities;
        unsigned int numberOfLines, skippedLines, commentLines, parsedLines;

        std::vector<EntityMapping> mappingsList;
};

inline
const std::string & EntityFileParser::getFilename() const { return entityFilename; }

inline
const std::vector<EntityMapping> & EntityFileParser::getEntityMappings() const { return mappingsList; }

inline
unsigned int EntityFileParser::getNumberOfEntities() const { return numberOfEntities; }

inline
unsigned int EntityFileParser::getNumberOfAssignedEntities() const { return numberOfAssignedEntities; }

#endif

