/**
 * C++ Class    Map File Parser
 *
 * Revision     1.0a (9th August 2010)
 * Programmer   Michael Allwright
 *
 * Purpose      Map File Parser is designed to parse the mappings between a network characteristic and a visualisation
 *              parameter. When parsing the class ingnores blank lines and lines beginning with '#' (commments),
 *              looking for lines matching the format:
 *              
 *              networkCharacteristic:statisticsMode:visualisationParameter
 *
 *              The statistic mode determines how the data will be processed before it is scaled. i.e. from of the data set
 *              find the minimum, maximum, average etc...
 *
**/

#ifndef _LTCPMON_MAPPARSER_
#define _LTCPMON_MAPPARSER_

#include <sstream>
#include <string>
#include <vector>

#include "tcpmapping.h"

class MapFileParser
{
    public:
    MapFileParser(const std::string & mapFilename);

    void parse();

    std::string generateReport() const;
    const std::string & getFilename() const;
    const std::vector<TcpMapping> & getMappings() const;

    private:
    std::string mapFilename;
    std::ifstream mapFile;

    unsigned int numberOfLines, skippedLines, commentLines, parsedLines;

    std::vector<TcpMapping> mappingsList;
};

inline
const std::vector<TcpMapping> & MapFileParser::getMappings() const { return mappingsList; }

inline
const std::string & MapFileParser::getFilename() const { return mapFilename; }

#endif

